@@ -10,6 +10,7 @@ class Migration(object):
     def migrate(self, agent):
         raise NotImplementedError()
 
+
 class Pyro4Migration(Migration):
     @Inject("ns_hostname")
     def __init__(self):
@@ -33,6 +34,23 @@ class Pyro4Migration(Migration):
         return Pyro4.Proxy(random.choice(agents.values()))
 
 
+class ParentMigration(Migration):
+    def migrate(self, agent):
+        try:
+            if random.random() > 0.95 and len(agent.parent.get_agents()) > 1 and len(
+                agent.parent.parent.get_agents()) > 1:
+                logger.debug("migrating!")
+                aggregate = self.__get_random_aggregate(agent)
+                logger.debug(aggregate.get_address())
+                aggregate.add_agent(agent.parent.remove_agent(agent))
+        except:
+            logging.exception("")
+
+    def __get_random_aggregate(self, agent):
+        siblings = list(agent.parent.parent.get_agents())
+        return random.choice(siblings)
+
+
 class NoMigration(Migration):
     def migrate(self, agent):
         pass
\ No newline at end of file
